@@ -383,7 +383,7 @@ static int scanmacho_archive(const char *filename, int fd, size_t len)
 	fatobj *fobj;
 	fatobj *walk;
 
-	ar = ar_open_fd(filename, fd);
+	ar = ar_open_fd(filename, fd, be_verbose);
 	if (ar == NULL)
 		return 1;
 
